@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backend.py 10357 2017-10-08 08:14:22Z David $
+# $Id: Backend.py 10370 2017-10-14 17:39:54Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-10-08 16:14:22 +0800 (Sun, 08 Oct 2017) $
-# $Revision: 10357 $
+# $Date: 2017-10-15 01:39:54 +0800 (Sun, 15 Oct 2017) $
+# $Revision: 10370 $
 
 from urllib import urlopen, urlencode, quote
 from django.core.mail.backends.base import BaseEmailBackend
@@ -124,11 +124,10 @@ class EmailBackend(BaseEmailBackend):
             token = self._getToken(app)
             title = utf8(email.subject)
             
-            if '$' in self.username and not '@' in self.username:
+            if '$' in email.from_email and not '@' in email.from_email:
                 fromMail = self.from_email
             else:
                 fromMail = email.from_email
-
             data = {
                 'token': token,
                 'title': title,
