@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 10364 2017-10-10 17:26:52Z David $
+# $Id: urls.py 10369 2017-10-14 09:46:18Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-10-11 01:26:52 +0800 (Wed, 11 Oct 2017) $
-# $Revision: 10364 $
+# $Date: 2017-10-14 17:46:18 +0800 (Sat, 14 Oct 2017) $
+# $Revision: 10369 $
 
 from django.conf.urls import url, include, patterns
 
@@ -54,4 +54,8 @@ urlpatterns = patterns('',
 
     # django-selectable.
     url(r'^newsletters/selectable/', include('selectable.urls')),
+
+    # resend error contact.
+    url(r'^newsletters/resend/(?P<newsletterId>\w+)',
+        views.resendErrorContact, name='resendErrorContact'),
 )
